symengine_py: Python wrappers for SymEngine
===========================================

Description
-----------

Python wrappers for SymEngine

License
-------

symengine.py is MIT licensed and uses several LGPL, BSD-3 and MIT
licensed libraries

Upstream Contact
----------------

https://github.com/symengine/symengine.py
